@@ -8,6 +8,7 @@ from .services import SSH_SERVERS
 
 class Credentials(object):
     """Captura les credencials de l'alias."""
+    VERBOSE = os.environ['PYDB_VERBOSE'] != 'False'
 
     def __init__(self, alias):
         self.host = SSH_SERVERS[alias]['host']
@@ -15,9 +16,10 @@ class Credentials(object):
         self.user = SSH_SERVERS[alias]['user']
 
     def logger(command, arguments=""):
-        print(self.host, self.port, self.user)
-        print(command)
-        print(arguments)
+        if (self.VERBOSE):
+            print(self.host, self.port, self.user)
+            print(command)
+            print(arguments)
 
 
 class SSH(Credentials):
